Class: Aws::ImportExport::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ImportExport::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-importexport/client.rb,
sig/client.rbs
Overview
An API client for ImportExport. To construct a client, you need to configure a :region and :credentials.
client = Aws::ImportExport::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelJobResponseSuccess, _CreateJobResponseSuccess, _GetShippingLabelResponseSuccess, _GetStatusResponseSuccess, _ListJobsResponseSuccess, _UpdateJobResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_job(params = {}) ⇒ Types::CancelJobOutput
This operation cancels a specified job.
-
#create_job(params = {}) ⇒ Types::CreateJobOutput
This operation initiates the process of scheduling an upload or download of your data.
-
#get_shipping_label(params = {}) ⇒ Types::GetShippingLabelOutput
This operation generates a pre-paid UPS shipping label that you will use to ship your device to AWS for processing.
-
#get_status(params = {}) ⇒ Types::GetStatusOutput
This operation returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsOutput
This operation returns the jobs associated with the requester.
-
#update_job(params = {}) ⇒ Types::UpdateJobOutput
You use this operation to change the parameters specified in the original manifest file by supplying a new manifest file.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
465 466 467 |
# File 'lib/aws-sdk-importexport/client.rb', line 465 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
840 841 842 |
# File 'lib/aws-sdk-importexport/client.rb', line 840 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
843 844 845 |
# File 'lib/aws-sdk-importexport/client.rb', line 843 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/aws-sdk-importexport/client.rb', line 813 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ImportExport') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-importexport' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job(params = {}) ⇒ Types::CancelJobOutput
This operation cancels a specified job. Only the job owner can cancel it. The operation fails if the job has already started or is complete.
85 |
# File 'sig/client.rbs', line 85
def cancel_job: (
|
#create_job(params = {}) ⇒ Types::CreateJobOutput
This operation initiates the process of scheduling an upload or download of your data. You include in the request a manifest that describes the data transfer specifics. The response to the request includes a job ID, which you can use in other operations, a signature that you use to identify your storage device, and the address where you should ship your storage device.
101 |
# File 'sig/client.rbs', line 101
def create_job: (
|
#get_shipping_label(params = {}) ⇒ Types::GetShippingLabelOutput
This operation generates a pre-paid UPS shipping label that you will use to ship your device to AWS for processing.
116 |
# File 'sig/client.rbs', line 116
def get_shipping_label: (
|
#get_status(params = {}) ⇒ Types::GetStatusOutput
This operation returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job. You can only return information about jobs you own.
152 |
# File 'sig/client.rbs', line 152
def get_status: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsOutput
This operation returns the jobs associated with the requester. AWS Import/Export lists the jobs in reverse chronological order based on the date of creation. For example if Job Test1 was created 2009Dec30 and Test2 was created 2010Feb05, the ListJobs operation would return Test2 followed by Test1.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
164 |
# File 'sig/client.rbs', line 164
def list_jobs: (
|
#update_job(params = {}) ⇒ Types::UpdateJobOutput
You use this operation to change the parameters specified in the original manifest file by supplying a new manifest file. The manifest file attached to this request replaces the original manifest file. You can only use the operation after a CreateJob request but before the data transfer starts and you can only use it on jobs you own.
178 |
# File 'sig/client.rbs', line 178
def update_job: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
833 834 835 |
# File 'lib/aws-sdk-importexport/client.rb', line 833 def waiter_names [] end |