Class: Aws::ImportExport::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ImportExport::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-importexport/client.rb
Overview
An API client for ImportExport. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ImportExport::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_job(params = {}) ⇒ Types::CancelJobOutput
This operation cancels a specified job.
-
#create_job(params = {}) ⇒ Types::CreateJobOutput
This operation initiates the process of scheduling an upload or download of your data.
-
#get_shipping_label(params = {}) ⇒ Types::GetShippingLabelOutput
This operation generates a pre-paid UPS shipping label that you will use to ship your device to AWS for processing.
-
#get_status(params = {}) ⇒ Types::GetStatusOutput
This operation returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsOutput
This operation returns the jobs associated with the requester.
-
#update_job(params = {}) ⇒ Types::UpdateJobOutput
You use this operation to change the parameters specified in the original manifest file by supplying a new manifest file.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
465 466 467 |
# File 'lib/aws-sdk-importexport/client.rb', line 465 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
840 841 842 |
# File 'lib/aws-sdk-importexport/client.rb', line 840 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
843 844 845 |
# File 'lib/aws-sdk-importexport/client.rb', line 843 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/aws-sdk-importexport/client.rb', line 813 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ImportExport') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-importexport' context[:gem_version] = '1.73.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job(params = {}) ⇒ Types::CancelJobOutput
This operation cancels a specified job. Only the job owner can cancel it. The operation fails if the job has already started or is complete.
497 498 499 500 |
# File 'lib/aws-sdk-importexport/client.rb', line 497 def cancel_job(params = {}, = {}) req = build_request(:cancel_job, params) req.send_request() end |
#create_job(params = {}) ⇒ Types::CreateJobOutput
This operation initiates the process of scheduling an upload or download of your data. You include in the request a manifest that describes the data transfer specifics. The response to the request includes a job ID, which you can use in other operations, a signature that you use to identify your storage device, and the address where you should ship your storage device.
557 558 559 560 |
# File 'lib/aws-sdk-importexport/client.rb', line 557 def create_job(params = {}, = {}) req = build_request(:create_job, params) req.send_request() end |
#get_shipping_label(params = {}) ⇒ Types::GetShippingLabelOutput
This operation generates a pre-paid UPS shipping label that you will use to ship your device to AWS for processing.
635 636 637 638 |
# File 'lib/aws-sdk-importexport/client.rb', line 635 def get_shipping_label(params = {}, = {}) req = build_request(:get_shipping_label, params) req.send_request() end |
#get_status(params = {}) ⇒ Types::GetStatusOutput
This operation returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job. You can only return information about jobs you own.
700 701 702 703 |
# File 'lib/aws-sdk-importexport/client.rb', line 700 def get_status(params = {}, = {}) req = build_request(:get_status, params) req.send_request() end |
#list_jobs(params = {}) ⇒ Types::ListJobsOutput
This operation returns the jobs associated with the requester. AWS Import/Export lists the jobs in reverse chronological order based on the date of creation. For example if Job Test1 was created 2009Dec30 and Test2 was created 2010Feb05, the ListJobs operation would return Test2 followed by Test1.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
751 752 753 754 |
# File 'lib/aws-sdk-importexport/client.rb', line 751 def list_jobs(params = {}, = {}) req = build_request(:list_jobs, params) req.send_request() end |
#update_job(params = {}) ⇒ Types::UpdateJobOutput
You use this operation to change the parameters specified in the original manifest file by supplying a new manifest file. The manifest file attached to this request replaces the original manifest file. You can only use the operation after a CreateJob request but before the data transfer starts and you can only use it on jobs you own.
804 805 806 807 |
# File 'lib/aws-sdk-importexport/client.rb', line 804 def update_job(params = {}, = {}) req = build_request(:update_job, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
833 834 835 |
# File 'lib/aws-sdk-importexport/client.rb', line 833 def waiter_names [] end |